# SDMX Schemas

This repository contains the SDMX schemas for the SDMX-JSON and SDMX-ML formats. 
The schemas are provided in the form of JSON Schema files and XSD files.

Included are the following schemas:

- SDMX-JSON 1.0 Schema
- SDMX-JSON 2.0 Schema
- SDMX-ML 1.0 Schema
- SDMX-ML 2.0 Schema
- SDMX-ML 2.1 Schema
- SDMX-ML 3.0 Schema
